![](images/stitchr-logo.png)

### Stitch together TCR coding nucleotide sequences from V/J/CDR3 information

##### Jamie Heather | CCR @ MGH | 2023

[The documentation for stitchr can be accessed at this link: https://jamieheather.github.io/stitchr/](https://jamieheather.github.io/stitchr/)



